# TimeframePolicyTemplate

A timeframe policy for providing access between a specific start and end time. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**start_time** | **datetime** | The start time when permission is given. Assumes UTC timezone unless otherwise provided inside the date-time as per RFC 3339.  | 
**end_time** | **datetime** | The end time when permission is removed. Assumes UTC timezone unless otherwise provided inside the date-time as per RFC 3339.  | 
**labels** | [**[LabelName]**](LabelName.md) | Restrict the timestamp to accesses for resources or users with one of these labels.  | 
**template_type** | **str** | The descriminator for the PolicyTemplate. Set this to &#x60;timeframe&#x60; | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


